import Koa from 'koa'
import dotenv from 'dotenv'
import route from 'koa-route'
import Debug from 'debug'
import koaBody from 'koa-body'

dotenv.config()
console.log = Debug('invoiceIssuer:app.ts')

const app = new Koa()
app.use(koaBody())

/**
 * GET /
 * @summary 返回欢迎信息。通常用于检查服务器是否正常运行。
 * @param {Koa.Context} ctx - Koa context object
 */
const getRoot = route.get('/', (ctx) => {
    ctx.body = 'Hello World'
})

/**
 * POST /payer
 * @summary 创建一个新的付款人。这个付款人与收据上标识的收款人信息分离，但内部数据库关联（以便检索）。
 * @param {Koa.Context} ctx - Koa context object
 */
const postPayer = route.post('/payer', async (ctx) => {
    // TODO: 请求头验证 bearer token

    const { name, address, abn, email } = ctx.request.body

    if (!name || !address || !email) {
        ctx.status = 400;
        ctx.body = { error: 'required_fields_missing' }
        return;
    }
})

// 导出路由
export { getRoot, postPayer }

const port = parseInt(process.env.PORT ?? '3000')
app.listen(port, () => {
    /**
     * Server listening callback
     * @summary Logs the server start message
     */
    console.log(`Server is running at http://localhost:${port}`)
})